package com.jiankangyouyi.cloud.assessment.model.entity.mongo;

import com.jiankangyouyi.cloud.assessment.model.dto.api.component.AssessmentHealthProblemDTO;
import com.jiankangyouyi.cloud.assessment.model.entity.mongo.component.QuestionLack;
import com.jiankangyouyi.cloud.core.base.entity.BaseMongoEntity;
import lombok.*;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.mapping.Document;

import java.util.List;

/**
 * 测评结果表
 *
 * @author : yangsongbo
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
@Document(collection = "assessment.question.back")
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "reportId_-1",
                        def = "{'reportId':-1}"
                ),
                @CompoundIndex(
                        name = "appId_-1_userId_-1_reportId_-1",
                        def = "{'appId': -1, 'userId': -1,'reportId':-1}"
                ),
        }
)
public class AssessmentQuestionBackDO extends BaseMongoEntity {

    private static final long serialVersionUID = 1L;

    /**
     * 配置ID，业务主键
     */
    private String reportId;

    /**
     * 测评项目ID
     */
    private String configId;

    /**
     * 业务类型
     */
    private String bizType;

    /**
     * 应用ID
     */
    private String appId;

    /**
     * 用户ID
     */
    private String userId;


    /**
     * 创建日期 yyyy-MM-dd
     */
    private String createDate;

    /**
     * 做过的测评题及选择结果
     */
    private List<QuestionLack> questionLacks;
    /**
     * 本次出题的健康问题
     */
    private List<AssessmentHealthProblemDTO> healthProblems;

    public static final String FIELD_REPORTID = "reportId";
    public static final String FIELD_BIZTYPE = "bizType";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_USERID = "userId";
    public static final String FIELD_CONFIGID = "configId";
    public static final String FIELD_CREATEDATE = "createDate";

}
