package com.jiankangyouyi.cloud.assessment.model.entity.mongo.life.style;

import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;

/**
 * 生活方式报告表
 *
 * @author : fengxuanjun
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "appId_-1_userId_-1_bizType_1_validStatus_1",
                        def = "{ 'appId': -1,'userId': -1,'bizType':1,'validStatus':1}",
                        unique = true
                ),
                @CompoundIndex(
                        name = "reportId_-1",
                        def = "{ 'reportId': -1}",
                        unique = true
                )
        }
)
@Document(collection = "v3.life.style.report")
public class LifeStyleReportDO implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    @Id
    private ObjectId id;

    /**
     * 修改时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime ;
    /**
     * 修改时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime ;

    /**
     * 创建日期 yyyy-MM-dd
     */
    private String createDate;

    /**
     * 报告ID，业务主键
     */
    @Indexed(unique = true)
    private String reportId;

    /**
     * 业务类型
     */
    private String bizType;

    /**
     * 应用ID，不能为空
     */
    private String appId;

    /**
     * 用户ID
     */
    private String userId;

    /**
     * 有效标识符
     */
    private String validStatus;



    public static final String FIELD_ID = "_id";
    public static final String FIELD_VALIDSTATUS = "validStatus";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_BIZTYPE = "bizType";
    public static final String FIELD_USERID = "userId";
    public static final String FIELD_CREATEDATE = "createDate";
    public static final String FIELD_REPORTID = "reportId";


}
