package com.jiankangyouyi.cloud.assessment.model.entity.mongo.life.style;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.assessment.model.entity.mongo.component.LifeStyleUserInfo;
import com.jiankangyouyi.cloud.assessment.model.entity.mongo.life.style.component.LifeStyleSchemeDetail;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.FieldNameConstants;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 生活方式报告-方案表
 *
 * @author : fengxuanjun
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "appId_-1_userId_-1_bizType_1_validStatus_1",
                        def = "{ 'appId': -1,'userId': -1,'bizType':1,'validStatus':1}"
                ),
        }
)
@Document(collection = "v3.life.style.report.scheme")
@FieldNameConstants
public class LifeStyleReportSchemeDO implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    @Id
    private ObjectId id;

    /**
     * 修改时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime ;
    /**
     * 修改时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime ;

    /**
     * 创建日期 yyyy-MM-dd
     */
    private String createDate;

    /**
     * 报告ID
     */
    private String reportId;

    /**
     * 方案ID
     */
    @Indexed(unique = true)
    private String schemeId;

    /**
     * 业务类型
     */
    private String bizType;

    /**
     * 应用ID，不能为空
     */
    private String appId;

    /**
     * 用户ID
     */
    private String userId;

    /**
     * 有效标识符
     */
    private String validStatus;

    /**
     * 用户生成方案信息
     */
    private LifeStyleUserInfo userInfo;
    /**
     * 方案详细列表 NOT NULL
     */
    private List<LifeStyleSchemeDetail> schemeDetails;



    public static final String FIELD_ID = "_id";
    public static final String FIELD_VALIDSTATUS = "validStatus";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_BIZTYPE = "bizType";
    public static final String FIELD_USERID = "userId";
    public static final String FIELD_CREATEDATE = "createDate";
    public static final String FIELD_SCHEMEID = "schemeId";
    public static final String FIELD_REPORTID = "reportId";


}
