package com.jiankangyouyi.cloud.assessment.model.entity.mongo.life.style;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.assessment.model.entity.mongo.life.style.component.LifeStyleSchemeDetail;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;

/**
 * 生活方式报告-方案阶段表
 *
 * @author : fengxuanjun
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "appId_-1_userId_-1_bizType_1_validStatus_1",
                        def = "{ 'appId': -1,'userId': -1,'bizType':1,'validStatus':1}"
                ),
                @CompoundIndex(
                        name = "schemeStageId_-1",
                        def = "{ 'schemeStageId': -1}"
                ),
        }
)
@Document(collection = "v3.life.style.report.scheme.stage")
public class LifeStyleReportSchemeStageDO implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    @Id
    private ObjectId id;

    /**
     * 修改时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime ;
    /**
     * 修改时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime ;

    /**
     * 创建日期 yyyy-MM-dd
     */
    private String createDate;

    /**
     * 报告ID
     */
    private String reportId;

    /**
     * 方案ID
     */
    private String schemeId;

    /**
     * 方案详情ID
     * 对应:方案表-方案详细-方案详情ID{@link LifeStyleSchemeDetail}
     */
    private String schemeDetailId;

    /**
     * 方案阶段ID
     */
    private String schemeStageId;

    /**
     * 业务类型
     */
    private String bizType;

    /**
     * 应用ID，不能为空
     */
    private String appId;

    /**
     * 用户ID
     */
    private String userId;

    /**
     * 当前阶段内打卡天数
     */
    private Integer punchCardDays;

    /**
     * 当前阶段
     * {@link com.jiankangyouyi.cloud.assessment.enums.assessment190101.LifeStyleSchemeStageEnum}
     */
    private Integer schemeStageNum;

    /**
     * 阶段开始日期 yyyy-MM-dd
     */
    private String stageStartDate;
    /**
     * 阶段结束日期 yyyy-MM-dd
     */
    private String stageEndDate;

    /**
     * 下一阶段开始日期 yyyy-MM-dd
     * 打卡次数大于等于5次 赋值
     * 使用：查看方案日期-阶段结束日期<=7,方案完成状态:true
     */
    private String nextStageStartDate;

    /**
     * 方案完成状态 true,false，默认false
     */
    private Boolean schemeFinishStatus;

    /**
     * 是否过期方案 true false，默认false，如果过期方案，打卡不做阶段流转操作
     */
    private Boolean schemeOverdueStatus;

    /**
     * 有效标识符
     */
    private String validStatus;






    public static final String FIELD_ID = "_id";
    public static final String FIELD_VALIDSTATUS = "validStatus";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_CREATEDATE = "createDate";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_BIZTYPE = "bizType";
    public static final String FIELD_USERID = "userId";
    public static final String FIELD_REPORTID = "reportId";
    public static final String FIELD_SCHEMEID = "schemeId";
    public static final String FIELD_SCHEMEDETAILID = "schemeDetailId";
    public static final String FIELD_SCHEMESTAGEID = "schemeStageId";
    public static final String FIELD_SCHEMESTAGENUM = "schemeStageNum";
    public static final String FIELD_SCHEMEFINISHSTATUS = "schemeFinishStatus";


}
