package com.jiankangyouyi.cloud.basedata.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.basedata.model.entity.mongo.component.ServiceArea;
import com.jiankangyouyi.cloud.basedata.model.entity.mongo.component.ServiceValue;
import com.jiankangyouyi.cloud.core.base.enums.ValidStatusEnum;
import lombok.AllArgsConstructor;
import lombok.Data;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;
import java.util.List;

/**
 * 封面配置表
 *
 * @author ：wangyalei
 * @date ：Created in 2021/7/12 6:39 下午
 */
@Data
@AllArgsConstructor
@Document(collection = "v3.health.assessment.cover.config")
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "appId_1_coverType_1",
                        def = "{'appId' : 1, 'coverType' : 1}",
                        unique = true
                )
        }
)
public class HealthAssessmentCoverConfigDO {

    @Id
    private ObjectId id;
    /**
     *  1、启用 2、禁用  {@link ValidStatusEnum}
     */
    private String validStatus;

    @DateTimeFormat(
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    @JsonFormat(
            timezone = "GMT+8",
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    private Date updateTime;
    @DateTimeFormat(
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    @JsonFormat(
            timezone = "GMT+8",
            pattern = "yyyy-MM-dd HH:mm:ss"
    )

    private Date createTime;
    /**
     * 封面id
     */
    @Indexed(unique = true)
    private String coverId;
    /**
     * 应用 id
     */
    private String appId;
    /**
     * 封面类型 {@link com.jiankangyouyi.cloud.basedata.enums.HealthAssessmentCoverConfigEnum}
     */
    private String coverType;
    /**
     * 服务简介
     */
    private String serviceProfile;
    /**
     * 服务范围
     */
    private List<ServiceArea> serviceAreas;
    /**
     * 服务价值
     */
    private List<ServiceValue> serviceValues;
    /**
     * 提示
     */
    private String reminder;



    public HealthAssessmentCoverConfigDO() {
        Date date = new Date();
        this.validStatus = ValidStatusEnum.VALID.getCode();
        this.updateTime = date;
        this.createTime = date;
    }

    public static final String FIELD_ID = "_id";
    public static final String FIELD_VALIDSTATUS = "validStatus";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_COVER_ID = "coverId";
    public static final String FIELD_COVER_TYPE = "coverType";
    public static final String FIELD_SERVICEPROFILE = "serviceProfile";
    public static final String FIELD_SERVICEAREAS = "serviceAreas";
    public static final String FIELD_SERVICEAREAS_TITLE = "serviceAreas.title";
    public static final String FIELD_SERVICEAREAS_IMAGE = "serviceAreas.image";
    public static final String FIELD_SERVICEAREAS_DESCRIPTION = "serviceAreas.description";
    public static final String FIELD_SERVICEVALUES = "serviceValues";
    public static final String FIELD_SERVICEVALUES_TITLE = "serviceValues.title";
    public static final String FIELD_SERVICEVALUES_DESCRIPTION = "serviceValues.description";
    public static final String FIELD_REMINDER = "reminder";

}
