package com.jiankangyouyi.cloud.data.center.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.core.base.enums.ValidStatusEnum;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;

/**
 * 分词词典表，语音记录时，用于分词的字典数据
 *
 * @author jingpeng
 * @description 分词词典表，语音记录时，用于分词的字典数据
 * @date 2020/11/2
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@Document(collection = "v3.custom.dictionary")
public class CustomDictionaryDO implements Serializable {
    public static final String COLLECTION_NAME = "v3.custom.dictionary";
    private static final long serialVersionUID = 1L;

    @Id
    private ObjectId id;

    /**
     * 更新时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime;

    /**
     * 创建时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /**
     * 词典值
     */
    private String dicValue;

    /**
     * 解析值
     */
    private String parseValue;

    /**
     * 词性
     */
    private String wordNature;

    /**
     * 数据来源
     */
    private String dataSource;

    /**
     * 有效标识 {@link ValidStatusEnum}
     */
    private String validStatus;

    public static final String FIELD_ID = "_id";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_DICVALUE = "dicValue";
    public static final String FIELD_PARSEVALUE = "parseValue";
    public static final String FIELD_WORDNATURE = "wordNature";
    public static final String FIELD_DATASOURCE = "dataSource";
    public static final String FIELD_VALIDSTATUS = "validStatus";

}
