package com.jiankangyouyi.cloud.data.center.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.core.base.enums.ValidStatusEnum;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;

/**
 * 自定义运动表
 *
 * @author jingpeng
 * @description 自定义运动表DO
 * @date 2020/11/2
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "appId_-1_userId_-1_recordDate_-1",
                        def = "{ 'appId' : -1, 'userId' : -1, 'recordDate' : -1 }"
                )
        }
)
@Document(collection = "v3.custom.exercise")
public class CustomExerciseDO implements Serializable {
    private static final long serialVersionUID = 1L;

    @Id
    private ObjectId id;

    /**
     * 更新时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime;

    /**
     * 创建时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /**
     * 业务类型
     */
    private String bizType;

    /**
     * 创建时间
     */
    private String createDate;

    /**
     * 应用id
     */
    private String appId;

    /**
     * 用户id
     */
    private String userId;

    /**
     * 运动id
     */
    @Indexed(unique = true)
    private String exerciseId;

    /**
     * 运动名称
     */
    private String exerciseName;

    /**
     * 食物图片
     */
    private String imageKey;

    /**
     * 数量
     */
    private Double quantity;

    /**
     * 单位
     */
    private String unit;

    /**
     * 能量（kcal）
     */
    private Integer energy;

    /**
     * 有效标识，1有效，2无效
     * {@link ValidStatusEnum}
     */
    private String validStatus;


    public static final String FIELD_ID = "_id";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_BIZTYPE = "bizType";
    public static final String FIELD_CREATEDATE = "createDate";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_USERID = "userId";
    public static final String FIELD_EXERCISEID = "exerciseId";
    public static final String FIELD_EXERCISENAME = "exerciseName";
    public static final String FIELD_IMAGEKEY = "imageKey";
    public static final String FIELD_QUANTITY = "quantity";
    public static final String FIELD_UNIT = "unit";
    public static final String FIELD_ENERGY = "energy";
    public static final String FIELD_VALIDSTATUS = "validStatus";

}
