package com.jiankangyouyi.cloud.food_match.model.entity.mongodb;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.jiankangyouyi.cloud.core.base.enums.ValidStatusEnum;
import com.jiankangyouyi.cloud.data.center.api.model.dto.response.EnergyBalancePlanInfoResponseDTO;
import com.jiankangyouyi.cloud.food_match.api.model.entity.match.FoodMatchV2ResponseInfo;
import com.jiankangyouyi.cloud.food_match.model.dto.request.match.MatchFoodV2RequestDTO;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.annotation.Version;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;





/**
 * 配餐结果信息
 *
 * @description: 配餐结果do
 * @author: zyj
 * @email: zhaoyujie@jiankangyouyi.com
 * @date: 2021/7/28 11:14 上午
 */
@Data
@EqualsAndHashCode(callSuper = true)
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "appId_1_bizType_1_userId_1_validStatus_1_planningDate_-1",
                        def = "{'appId' : 1,'bizType':1,'userId':1,'validStatus':1,'planningDate':-1}",
                        unique = true
                ),
                @CompoundIndex(
                        name = "createTime",
                        def = "{'createTime' : 1}"
                ),
                @CompoundIndex(
                        name = "updateTime",
                        def = "{'updateTime' : 1}"
                ),
                @CompoundIndex(
                        name = "planningDate_-1_appId_-1_userId_-1",
                        def = "{'planningDate' : -1,'appId' : -1,'userId':-1}"
                ),
                @CompoundIndex(
                        name = "userId_-1_planningDate_-1",
                        def = "{'userId':-1,'planningDate' : -1}"
                )
        }
)
@Document(collection = "v3.food_match.res")
public class FoodMatchResDO extends FoodMatchV2ResponseInfo {

    private static final long serialVersionUID = 1L;
    @Id
    private ObjectId id;

    /**
     * 用户id
     */
    private String userId;
    /**
     * 业务类型
     */
    private String bizType;
    /**
     * appId
     */
    private String appId;

    /**
     * 配餐日期
     */
    private String planningDate;

    /**
     * 配餐请求参数
     */
    private MatchFoodV2RequestDTO foodMatchRequestDTO;

    /**
     * 能量平衡计划
     */
    private EnergyBalancePlanInfoResponseDTO energyBalancePlan;

    /**
     * 数据状态
     * {@link com.jiankangyouyi.cloud.core.base.enums.ValidStatusEnum}
     */
    private String validStatus = ValidStatusEnum.VALID.getCode();

    @Version
    private Long version;

    /**
     * 创建时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    @Indexed
    private Date createTime = new Date();

    /**
     * 修改时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    @Indexed
    private Date updateTime = new Date();

    public static final String FIELD_ID = "_id";
    public static final String FIELD_USERID = "userId";
    public static final String FIELD_BIZTYPE = "bizType";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_PLANNINGDATE = "planningDate";
    public static final String FIELD_VALIDSTATUS = "validStatus";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_BREAKFASTRES = "breakfastRes";
    public static final String FIELD_BREAKFASTRES_FOODS = "breakfastRes.foods";
    public static final String FIELD_BREAKFASTRES_FOODS_FOODID = "breakfastRes.foods.foodId";
    public static final String FIELD_BREAKFASTRES_FOODS_FOODNAME = "breakfastRes.foods.foodName";
    public static final String FIELD_BREAKFASTRES_FOODS_GRAM = "breakfastRes.foods.gram";
    public static final String FIELD_BREAKFASTRES_FOODS_CARBOHYDRATE = "breakfastRes.foods.carbohydrate";
    public static final String FIELD_BREAKFASTRES_FOODS_PROTEIN = "breakfastRes.foods.protein";
    public static final String FIELD_BREAKFASTRES_FOODS_FAT = "breakfastRes.foods.fat";
    public static final String FIELD_BREAKFASTRES_FOODS_ENERGY = "breakfastRes.foods.energy";
    public static final String FIELD_BREAKFASTRES_PROTEIN = "breakfastRes.protein";
    public static final String FIELD_BREAKFASTRES_FAT = "breakfastRes.fat";
    public static final String FIELD_BREAKFASTRES_CARBOHYDRATE = "breakfastRes.carbohydrate";
    public static final String FIELD_BREAKFASTRES_ENERGY = "breakfastRes.energy";
    public static final String FIELD_BREAKFASTEXTRARES = "breakfastExtraRes";
    public static final String FIELD_BREAKFASTEXTRARES_FOODS = "breakfastExtraRes.foods";
    public static final String FIELD_BREAKFASTEXTRARES_FOODS_FOODID = "breakfastExtraRes.foods.foodId";
    public static final String FIELD_BREAKFASTEXTRARES_FOODS_FOODNAME = "breakfastExtraRes.foods.foodName";
    public static final String FIELD_BREAKFASTEXTRARES_FOODS_GRAM = "breakfastExtraRes.foods.gram";
    public static final String FIELD_BREAKFASTEXTRARES_FOODS_CARBOHYDRATE = "breakfastExtraRes.foods.carbohydrate";
    public static final String FIELD_BREAKFASTEXTRARES_FOODS_PROTEIN = "breakfastExtraRes.foods.protein";
    public static final String FIELD_BREAKFASTEXTRARES_FOODS_FAT = "breakfastExtraRes.foods.fat";
    public static final String FIELD_BREAKFASTEXTRARES_FOODS_ENERGY = "breakfastExtraRes.foods.energy";
    public static final String FIELD_BREAKFASTEXTRARES_PROTEIN = "breakfastExtraRes.protein";
    public static final String FIELD_BREAKFASTEXTRARES_FAT = "breakfastExtraRes.fat";
    public static final String FIELD_BREAKFASTEXTRARES_CARBOHYDRATE = "breakfastExtraRes.carbohydrate";
    public static final String FIELD_BREAKFASTEXTRARES_ENERGY = "breakfastExtraRes.energy";
    public static final String FIELD_LUNCHRES = "lunchRes";
    public static final String FIELD_LUNCHRES_FOODS = "lunchRes.foods";
    public static final String FIELD_LUNCHRES_FOODS_FOODID = "lunchRes.foods.foodId";
    public static final String FIELD_LUNCHRES_FOODS_FOODNAME = "lunchRes.foods.foodName";
    public static final String FIELD_LUNCHRES_FOODS_GRAM = "lunchRes.foods.gram";
    public static final String FIELD_LUNCHRES_FOODS_CARBOHYDRATE = "lunchRes.foods.carbohydrate";
    public static final String FIELD_LUNCHRES_FOODS_PROTEIN = "lunchRes.foods.protein";
    public static final String FIELD_LUNCHRES_FOODS_FAT = "lunchRes.foods.fat";
    public static final String FIELD_LUNCHRES_FOODS_ENERGY = "lunchRes.foods.energy";
    public static final String FIELD_LUNCHRES_PROTEIN = "lunchRes.protein";
    public static final String FIELD_LUNCHRES_FAT = "lunchRes.fat";
    public static final String FIELD_LUNCHRES_CARBOHYDRATE = "lunchRes.carbohydrate";
    public static final String FIELD_LUNCHRES_ENERGY = "lunchRes.energy";
    public static final String FIELD_LUNCHEXTRARES = "lunchExtraRes";
    public static final String FIELD_LUNCHEXTRARES_FOODS = "lunchExtraRes.foods";
    public static final String FIELD_LUNCHEXTRARES_FOODS_FOODID = "lunchExtraRes.foods.foodId";
    public static final String FIELD_LUNCHEXTRARES_FOODS_FOODNAME = "lunchExtraRes.foods.foodName";
    public static final String FIELD_LUNCHEXTRARES_FOODS_GRAM = "lunchExtraRes.foods.gram";
    public static final String FIELD_LUNCHEXTRARES_FOODS_CARBOHYDRATE = "lunchExtraRes.foods.carbohydrate";
    public static final String FIELD_LUNCHEXTRARES_FOODS_PROTEIN = "lunchExtraRes.foods.protein";
    public static final String FIELD_LUNCHEXTRARES_FOODS_FAT = "lunchExtraRes.foods.fat";
    public static final String FIELD_LUNCHEXTRARES_FOODS_ENERGY = "lunchExtraRes.foods.energy";
    public static final String FIELD_LUNCHEXTRARES_PROTEIN = "lunchExtraRes.protein";
    public static final String FIELD_LUNCHEXTRARES_FAT = "lunchExtraRes.fat";
    public static final String FIELD_LUNCHEXTRARES_CARBOHYDRATE = "lunchExtraRes.carbohydrate";
    public static final String FIELD_LUNCHEXTRARES_ENERGY = "lunchExtraRes.energy";
    public static final String FIELD_SUPPERRES = "supperRes";
    public static final String FIELD_SUPPERRES_FOODS = "supperRes.foods";
    public static final String FIELD_SUPPERRES_FOODS_FOODID = "supperRes.foods.foodId";
    public static final String FIELD_SUPPERRES_FOODS_FOODNAME = "supperRes.foods.foodName";
    public static final String FIELD_SUPPERRES_FOODS_GRAM = "supperRes.foods.gram";
    public static final String FIELD_SUPPERRES_FOODS_CARBOHYDRATE = "supperRes.foods.carbohydrate";
    public static final String FIELD_SUPPERRES_FOODS_PROTEIN = "supperRes.foods.protein";
    public static final String FIELD_SUPPERRES_FOODS_FAT = "supperRes.foods.fat";
    public static final String FIELD_SUPPERRES_FOODS_ENERGY = "supperRes.foods.energy";
    public static final String FIELD_SUPPERRES_PROTEIN = "supperRes.protein";
    public static final String FIELD_SUPPERRES_FAT = "supperRes.fat";
    public static final String FIELD_SUPPERRES_CARBOHYDRATE = "supperRes.carbohydrate";
    public static final String FIELD_SUPPERRES_ENERGY = "supperRes.energy";
    public static final String FIELD_SUPPEREXTRARES = "supperExtraRes";
    public static final String FIELD_SUPPEREXTRARES_FOODS = "supperExtraRes.foods";
    public static final String FIELD_SUPPEREXTRARES_FOODS_FOODID = "supperExtraRes.foods.foodId";
    public static final String FIELD_SUPPEREXTRARES_FOODS_FOODNAME = "supperExtraRes.foods.foodName";
    public static final String FIELD_SUPPEREXTRARES_FOODS_GRAM = "supperExtraRes.foods.gram";
    public static final String FIELD_SUPPEREXTRARES_FOODS_CARBOHYDRATE = "supperExtraRes.foods.carbohydrate";
    public static final String FIELD_SUPPEREXTRARES_FOODS_PROTEIN = "supperExtraRes.foods.protein";
    public static final String FIELD_SUPPEREXTRARES_FOODS_FAT = "supperExtraRes.foods.fat";
    public static final String FIELD_SUPPEREXTRARES_FOODS_ENERGY = "supperExtraRes.foods.energy";
    public static final String FIELD_SUPPEREXTRARES_PROTEIN = "supperExtraRes.protein";
    public static final String FIELD_SUPPEREXTRARES_FAT = "supperExtraRes.fat";
    public static final String FIELD_SUPPEREXTRARES_CARBOHYDRATE = "supperExtraRes.carbohydrate";
    public static final String FIELD_SUPPEREXTRARES_ENERGY = "supperExtraRes.energy";
    public static final String FIELD_PROTEIN = "protein";
    public static final String FIELD_FAT = "fat";
    public static final String FIELD_CARBOHYDRATE = "carbohydrate";
    public static final String FIELD_ENERGY = "energy";
    public static final String FIELD_FOODMATCHREQUESTDTO = "foodMatchRequestDTO";
}
