package com.jiankangyouyi.cloud.iotdata.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;

/**
 * 设备激活表
 *
 * @author : yangsongbo
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "appId_-1_deviceId_1_bizType_1",
                        def = "{'appId':-1,'deviceId':1,'bizType':1}",
                        unique = true
                ),
                @CompoundIndex(
                        name = "appId_-1_bizType_1_activeDate_-1",
                        def = "{'appId':-1,'bizType':1,'activeDate':-1}"
                )
        }
)
@Document(collection = "v3.device.active")
public class DeviceActiveDO implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    @Id
    private ObjectId id;

    /**
     * 更新时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime;

    /**
     * 创建时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /**
     * 创建日期
     */
    private String createDate;

    /**
     * 应用ID
     */
    private String appId;

    /**
     * 设备ID
     */
    private String deviceId;

    /**
     * 业务类型
     */
    private String bizType;

    /**
     * 最后使用用户ID
     */
    private String userId;

    /**
     * 激活状态 1 已激活 2 未激活
     */
    private String activeStatus;

    /**
     * 激活时间
     */
    private Date activeTime;

    /**
     * 激活日期 yyyy-MM-dd
     */
    private String activeDate;

    /**
     * 最后活跃日期 yyyy-MM-dd
     */
    private String lastDate;

    public static final String FIELD_ID = "_id";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_CREATEDATE = "createDate";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_DEVICEID = "deviceId";
    public static final String FIELD_BIZTYPE = "bizType";
    public static final String FIELD_USERID = "userId";
    public static final String FIELD_ACTIVESTATUS = "activeStatus";
    public static final String FIELD_ACTIVETIME = "activeTime";
    public static final String FIELD_ACTIVEDATE = "activeDate";
    public static final String FIELD_LASTDATE = "lastDate";


}
