package com.jiankangyouyi.cloud.iotdata.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;

/**
 * 设备电量表
 *
 * @author : yangsongbo
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "appId_-1_deviceId_1_bizType_1_createTime_-1",
                        def = "{'appId':-1,'deviceId':1,'bizType':1,'createTime':-1}"
                )
        }
)
@Document(collection = "v3.device.battery")
public class DeviceBatteryDO implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     * <p>
     * 当主键设置为id时，执行DeviceBatteryService.findList(String appId, Collection<String> deviceIds, String bizType, int rangeHours)
     * 方法时，报 org.springframework.data.mapping.context.InvalidPersistentPropertyPath: No property '_id' found on...错误，定义成_id
     * 后执行成功。
     * <p>
     * 因此，主键定义为_id，与数据库字段一致
     */
    @Id
    private ObjectId _id;

    /**
     * 创建时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /**
     * 创建日期
     */
    private String createDate;

    /**
     * 应用ID
     */
    private String appId;

    /**
     * 设备ID
     */
    private String deviceId;

    /**
     * 业务类型
     */
    private String bizType;

    /**
     * 电量（百分比）
     */
    private Integer battery;

    /**
     * 保存的用户，可以为空
     */
    private String userId;

    public static final String FIELD_ID = "_id";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_CREATEDATE = "createDate";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_DEVICEID = "deviceId";
    public static final String FIELD_BIZTYPE = "bizType";
    public static final String FIELD_BATTERY = "battery";
    public static final String FIELD_USERID = "userId";


}
