package com.jiankangyouyi.cloud.iotdata.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;

/**
 * 设备定位数据表
 *
 * @author : yangsongbo
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "appId_-1_bizType_1_deviceId_-1_userId_-1_createDate_-1_validStatus_1",
                        def = "{ 'appId': -1,'bizType': 1,'deviceId':-1,'userId':-1,'createDate':-1,'validStatus':1}"
                )
        }
)
@Document(collection = "v3.device.location")
public class DeviceLocationDO implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    @Id
    private ObjectId id;

    /**
     * 更新时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime;

    /**
     * 创建时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /**
     * 创建日期
     */
    private String createDate;

    /**
     * 应用ID
     */
    private String appId;

    /**
     * 业务类型
     */
    private String bizType;

    /**
     * 设备ID
     */
    private String deviceId;

    /**
     * 用户ID
     */
    private String userId;

    /**
     * 地图类型
     */
    private String mapType;

    /**
     * 经度
     */
    private String longitude;

    /**
     * 纬度
     */
    private String latitude;

    /**
     * 有效标识
     */
    private String validStatus;


    public static final String FIELD_ID = "_id";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_CREATEDATE = "createDate";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_BIZTYPE = "bizType";
    public static final String FIELD_DEVICEID = "deviceId";
    public static final String FIELD_USERID = "userId";
    public static final String FIELD_MAPTYPE = "mapType";
    public static final String FIELD_LONGITUDE = "longitude";
    public static final String FIELD_LATITUDE = "latitude";
    public static final String FIELD_VALIDSTATUS = "validStatus";

}
