package com.jiankangyouyi.cloud.iotdata.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 设备指标记录表
 *
 * @author : yangsongbo
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "appId_-1_userId_-1_deviceId_1_bizType_1_indicatorType_1",
                        def = "{'appId':-1,'userId':-1,'deviceId':1,'bizType':1,'indicatorType':1}"
                )
        }
)
@Document(collection = "v3.iot.record.body.indicator")
@Builder
public class IotRecordBodyIndicatorDO implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    @Id
    private ObjectId _id;

    /**
     * 更新时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime;

    /**
     * 创建时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /**
     * 记录状态  {@link com.jiankangyouyi.cloud.iot.enums.common.RecordStatusEnum}
     */
    private String recordStatus;

    /**
     * 记录ID
     */
    @Indexed(unique = true)
    private String recordId;

    /**
     * 批次号
     */
    @Indexed
    private String batchId;

    /**
     * 记录日期 yyyy-MM-dd
     */
    private String recordDate;

    /**
     * 记录时间，与创建时间有区别，记录时间表示当前记录数据产生的时间
     */
    private Date recordTime;

    /**
     * 应用ID,当记录状态为待认领时，appId设置为默认值 "0"
     */
    private String appId;

    /**
     * 用户ID，当记录状态为待认领时，userId设置为默认值 "0"
     */
    private String userId;

    /**
     * 业务类型
     */
    private String bizType;

    /**
     * 设备ID
     */
    private String deviceId;

    /**
     * 设备名称
     */
    private String deviceName;

    /**
     * 指标类型 {@link com.jiankangyouyi.cloud.data.center.api.enums.IndicatorEnum}
     */
    private String indicatorType;

    /**
     * 指标值
     */
    private String indicatorValue;

    /**
     * 身体指标标签  目前血糖用药情况 分类 {@link com.jiankangyouyi.cloud.data.center.api.enums.BloodGlucoseTagEnum}
     */
    private List<Integer> indicatorTagCodes;


    public static final String FIELD_ID = "_id";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";
    public static final String FIELD_VALIDSTATUS = "recordStatus";
    public static final String FIELD_RECORDID = "recordId";
    public static final String FIELD_BATCH_ID = "batchId";
    public static final String FIELD_RECORDDATE = "recordDate";
    public static final String FIELD_RECORDTIME = "recordTime";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_USERID = "userId";
    public static final String FIELD_BIZTYPE = "bizType";
    public static final String FIELD_DEVICEID = "deviceId";
    public static final String FIELD_INDICATORTYPE = "indicatorType";
    public static final String FIELD_INDICATORVALUE = "indicatorValue";
    public static final String FIELD_RECORD_STATUS = "recordStatus";
    public static final String FIELD_INDICATOR_TAG_CODES = "indicatorTagCodes";
    public static final String FIELD_VERSION_ID = "batchId";
    public static final String FIELD_DEVICE_NAME = "deviceName";

}
