package com.june.entitytodbdoc.utils;

import org.apache.commons.lang3.StringUtils;

import java.io.File;
import java.util.HashMap;
import java.util.Map;

/**
 * jar 路径和包名映射
 * @author june
 */
public class JarPathAndPackageMapping {

    private static final String PATH_PREFIX = "D:\\work\\idea\\june\\entity-to-db-doc\\entity-to-db-doc\\target\\distro-javadoc-sources\\";
    private static final String LOCAL_PATH_PREFIX = "D:\\work\\idea\\june\\entity-to-db-doc\\entity-to-db-doc\\src\\main\\java\\";
    /**
     * key 是包名前缀，value 是 文件路径前缀
     */
    private static final Map<String, String> MAPPING = new HashMap<>();

    static {
        mappingJar("com.jiankangyouyi.cloud.basedata.api", "health-cloud-base-data-api-2.2-TK-SNAPSHOT-sources");
        mappingJar("com.jiankangyouyi.cloud.assessment.api", "health-cloud-assessment-api-1.1-TK-SNAPSHOT-sources");
        mappingJar("com.jiankangyouyi.cloud.data.center.api", "health-cloud-data-center-api-2.2.1.1-TK-SNAPSHOT-sources");
        mappingJar("com.jiankangyouyi.cloud.food_match.api", "food-match-api-2.2.2-TK-SNAPSHOT-sources");
        mappingJar("com.jiankangyouyi.cloud.motorplan.api", "health-cloud-motor-plan-api-2.2.1-TK-SNAPSHOT-sources");
        mappingJar("com.jiankangyouyi.cloud.iot.api", "health-cloud-iot-data-api-1.0-TK-SNAPSHOT-sources");
    }

    private static void mappingJar(String packageName, String path) {
        MAPPING.put(packageName, PATH_PREFIX + path + "\\");
    }


    /**
     * 获取在jar包中的文件路径，如果不在jar包中返回null
     *
     * @param classFullName 全路径名称
     * @return classDoc
     */
    public static String getInJarClassPath(String classFullName) {
        if (StringUtils.isBlank(classFullName)) {
            return null;
        }
        for (Map.Entry<String, String> entry : MAPPING.entrySet()) {
            boolean isMatch = classFullName.startsWith(entry.getKey());
            if (!isMatch) {
                continue;
            }
            return entry.getValue() + packageToPath(classFullName);
        }
        // 从当前目录找下
        File file = new File(LOCAL_PATH_PREFIX + packageToPath(classFullName));
        if (file.exists()) {
            return file.getAbsolutePath();
        }
        return file.getPath();
    }

    private static String packageToPath(String packageName){
        return packageName.replace(".", "\\") + ".java";
    }

    public static void main(String[] args) {
        System.out.println(packageToPath("com.jiankangyouyi.cloud.basedata.api.model.entity.foodv4.FoodProcess"));
    }

}
